@@ -10,11 +10,11 @@ test_that("Code Lint", {
     #lintr::commented_code_linter(),
     #lintr::infix_spaces_linter(), #(73)
     #lintr::line_length_linter(), #(181)
-    lintr::no_tab_linter(),
+    lintr::whitespace_linter(),
     #lintr::object_usage_linter(),
     #lintr::snake_case_linter(),
     lintr::object_length_linter(),
-    lintr::single_quotes_linter(),
+    lintr::quotes_linter(),
     lintr::spaces_inside_linter(),
     #lintr::spaces_left_parentheses_linter(),
     lintr::trailing_blank_lines_linter(),
